(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
    typeof define === 'function' && define.amd ? define('@nonoll/code-snippet/event', ['exports'], factory) :
    (global = global || self, factory((global.nonoll = global.nonoll || {}, global.nonoll['code-snippet'] = global.nonoll['code-snippet'] || {}, global.nonoll['code-snippet'].event = {})));
}(this, (function (exports) { 'use strict';

    /**
     * empty function
     * @alias noop
     * @export
     */
    function noop() { }

    /**
     * @export
     * @class EventEmitter
     * @alias event/EventEmitter
     * @memberof event
     */
    var EventEmitter = /** @class */ (function () {
        function EventEmitter() {
            this.events = [];
        }
        /**
         * 이벤트 감지 등록
         * @param {string} eventName
         * @param {TypeVoidFunction} [listener={@link noop}]
         * @param {*} [context]
         * @returns {EventEmitter}
         * @memberof EventEmitter
         */
        EventEmitter.prototype.on = function (eventName, listener, context) {
            if (listener === void 0) { listener = noop; }
            this.events.push({ eventName: eventName, listener: listener, context: context });
            return this;
        };
        /**
         * 이벤트 감지 해제
         * @param {string} eventName
         * @param {TypeVoidFunction} [listener]
         * @returns {EventEmitter}
         * @memberof EventEmitter
         */
        EventEmitter.prototype.off = function (eventName, listener) {
            // tslint:disable-next-line: max-line-length
            var matched = this.events.findIndex(function (regEvent) { return regEvent.eventName === eventName && (listener ? regEvent.listener === listener : true); });
            // tslint:disable-next-line: no-bitwise
            if (!~matched) {
                return;
            }
            this.events.splice(matched, 1);
            return this;
        };
        /**
         * 이벤트 1회 감지 등록
         * @param {string} eventName
         * @param {TypeVoidFunction} [listener={@link noop}]
         * @param {*} [context]
         * @returns {EventEmitter}
         * @memberof EventEmitter
         */
        EventEmitter.prototype.once = function (eventName, listener, context) {
            var _this = this;
            if (listener === void 0) { listener = noop; }
            var onceWrapper = function () {
                var values = [];
                for (var _i = 0; _i < arguments.length; _i++) {
                    values[_i] = arguments[_i];
                }
                _this.off(eventName, onceWrapper);
                listener.apply(context || listener, values);
            };
            this.on(eventName, onceWrapper, context);
            return this;
        };
        /**
         * 이벤트 전파
         * @param {string} eventName
         * @param {...any[]} values
         * @returns {EventEmitter}
         * @memberof EventEmitter
         */
        EventEmitter.prototype.emit = function (eventName) {
            var values = [];
            for (var _i = 1; _i < arguments.length; _i++) {
                values[_i - 1] = arguments[_i];
            }
            this.events.forEach(function (regEvent) {
                if (regEvent.eventName === eventName) {
                    regEvent.listener.apply(regEvent.context || regEvent.listener, values);
                }
            });
            return this;
        };
        /**
         * 이벤트 전파
         * @param {string} eventName
         * @param {...any[]} values
         * @returns {EventEmitter}
         * @memberof EventEmitter
         */
        EventEmitter.prototype.fire = function (eventName) {
            var values = [];
            for (var _i = 1; _i < arguments.length; _i++) {
                values[_i - 1] = arguments[_i];
            }
            this.emit(eventName, values);
            return this;
        };
        return EventEmitter;
    }());

    exports.EventEmitter = EventEmitter;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=nonoll-code-snippet-event.umd.js.map
