import { TypeVoidFunction } from '../types/voidFunction';
/**
 * @export
 * @class EventEmitter
 * @alias event/EventEmitter
 * @memberof event
 */
export declare class EventEmitter {
    private events;
    constructor();
    /**
     * 이벤트 감지 등록
     * @param {string} eventName
     * @param {TypeVoidFunction} [listener={@link noop}]
     * @param {*} [context]
     * @returns {EventEmitter}
     * @memberof EventEmitter
     */
    on(eventName: string, listener?: TypeVoidFunction, context?: any): EventEmitter;
    /**
     * 이벤트 감지 해제
     * @param {string} eventName
     * @param {TypeVoidFunction} [listener]
     * @returns {EventEmitter}
     * @memberof EventEmitter
     */
    off(eventName: string, listener?: TypeVoidFunction): EventEmitter;
    /**
     * 이벤트 1회 감지 등록
     * @param {string} eventName
     * @param {TypeVoidFunction} [listener={@link noop}]
     * @param {*} [context]
     * @returns {EventEmitter}
     * @memberof EventEmitter
     */
    once(eventName: string, listener?: TypeVoidFunction, context?: any): EventEmitter;
    /**
     * 이벤트 전파
     * @param {string} eventName
     * @param {...any[]} values
     * @returns {EventEmitter}
     * @memberof EventEmitter
     */
    emit(eventName: string, ...values: any[]): EventEmitter;
    /**
     * 이벤트 전파
     * @param {string} eventName
     * @param {...any[]} values
     * @returns {EventEmitter}
     * @memberof EventEmitter
     */
    fire(eventName: string, ...values: any[]): EventEmitter;
}
